.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install tg-pubsub

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv tg-pubsub
    $ pip install tg-pubsub


Add to INSTALLED_APPS::

    INSTALLED_APPS = (
        ...
        'tg_pubsub',
    )
